"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parse = exports.parseSuiteName = exports.splitLines = void 0;
const lodash_1 = __importDefault(require("lodash"));
const stripcolorcodes_1 = __importDefault(require("stripcolorcodes"));
exports.splitLines = (stdout) => (stripcolorcodes_1.default(stdout).split('\n'));
const getErrorSeparatorLineNumber = (lines) => (lodash_1.default.findIndex(lines, l => l.includes('TEST FAILURE')));
exports.parseSuiteName = ({ suites, lines }) => {
    const suiteNames = Object.keys(suites);
    let currentSuite;
    return lines
        .slice(getErrorSeparatorLineNumber(lines))
        .map(line => {
        const match = /^\s+✖\s+(.+)$/.exec(line);
        const suiteName = match && suiteNames.find(suite => suite.endsWith(match[1])) || undefined;
        currentSuite = suiteName || currentSuite;
        return {
            suiteName: currentSuite,
            line
        };
    })
        .filter(r => !!r.suiteName);
};
exports.parse = ({ suites, stdout }) => (exports.parseSuiteName({ suites, lines: exports.splitLines(stdout) })
    .map(r => {
    const match = /\s+–\s+(.+)\s+\(.+\)$/.exec(r.line);
    return {
        suiteName: r.suiteName,
        testName: (match && match[1]) || undefined
    };
})
    .filter(r => r.suiteName && r.testName)
    .reduce((acc, next) => {
    acc[next.suiteName] = acc[next.suiteName] || next;
    return acc;
}, {}));
//# sourceMappingURL=failureParser.js.map