"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parse = exports.parseDirectoryNode = exports.parseChildNode = exports.getTestNames = exports.isTestSuite = exports.isTestCaseName = void 0;
const lodash_1 = __importDefault(require("lodash"));
const path_1 = __importDefault(require("path"));
/**
 * Assume any key with a whitespace is a test case
 * (i.e. two or more words making up a test case sentence)
 */
exports.isTestCaseName = (str) => /\s/g.test(str);
exports.isTestSuite = (obj) => (lodash_1.default.some(obj, (_v, key) => exports.isTestCaseName(key)));
exports.getTestNames = (testSuite) => Object.keys(testSuite)
    .filter(testCaseName => !['before', 'beforeEach', 'after', 'afterEach'].includes(testCaseName))
    .filter(testCaseName => testCaseName[0] !== '@');
const isTestNames = (value) => Array.isArray(value);
exports.parseChildNode = (node) => (exports.isTestSuite(node)
    ? exports.getTestNames(node)
    : exports.parseDirectoryNode(node));
exports.parseDirectoryNode = (dirNode) => {
    return Object.keys(dirNode).reduce((result, childDir) => {
        const childNode = dirNode[childDir];
        const childResult = exports.parseChildNode(childNode);
        if (isTestNames(childResult)) {
            result[childDir] = childResult;
        }
        else {
            Object.keys(childResult).forEach(childKey => {
                result[`${childDir}${path_1.default.sep}${childKey}`] = childResult[childKey];
            });
        }
        return result;
    }, {});
};
exports.parse = exports.parseDirectoryNode;
//# sourceMappingURL=suitesParser.js.map