"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.exec = void 0;
const chalk_1 = __importDefault(require("chalk"));
const child_process_1 = require("child_process");
const dataCollector_1 = require("../utils/dataCollector");
const toExecArgs_1 = require("./toExecArgs");
exports.exec = (executable, args) => new Promise((resolve, reject) => {
    const execArgs = toExecArgs_1.toExecArgs(args);
    console.log(chalk_1.default.grey(`Executing:  ${[executable, ...execArgs].join(' ')}`));
    const childProcess = child_process_1.spawn(executable, execArgs);
    childProcess.stdout.pipe(process.stdout);
    childProcess.stderr.pipe(process.stderr);
    const stdoutCollector = dataCollector_1.dataCollector(childProcess.stdout);
    const stderrCollector = dataCollector_1.dataCollector(childProcess.stderr);
    childProcess.on('close', (code) => {
        const stdout = stdoutCollector().toString();
        const stderr = stderrCollector().toString();
        if (code !== 0) {
            reject({ code, stdout, stderr });
            return;
        }
        resolve({ code, stdout, stderr });
    });
});
//# sourceMappingURL=exec.js.map