"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCommonExtension = void 0;
const lodash_1 = __importDefault(require("lodash"));
const config_1 = require("../actions/config");
const nightwatch_1 = require("../actions/nightwatch");
const getEnvironments_1 = require("../selectors/getEnvironments");
const getTestFailures_1 = require("../selectors/getTestFailures");
const hasEnvironment_1 = require("../selectors/hasEnvironment");
const withoutVorpal_1 = require("./withoutVorpal");
const testFailureName = (failure) => (`${failure.suiteName}: "${failure.testName}"`);
const createCommonExtension = (store) => vorpal => [
    vorpal
        .command('failures list', 'List all tests that failed in the previous run')
        .alias('failures ls', 'fls')
        .action(() => {
        const failures = getTestFailures_1.getTestFailures(store.getState());
        if (Object.keys(failures).length === 0) {
            vorpal.log('No tests failed on the last run.');
            return Promise.resolve();
        }
        const output = Object.keys(failures)
            .map(k => failures[k])
            .map(f => testFailureName(f))
            .join('\n');
        vorpal.log(output);
        return Promise.resolve();
    }),
    vorpal
        .command('failures run', 'Run all tests that failed in the previous run')
        .alias('fr')
        .action(function failuresRun() {
        const failures = getTestFailures_1.getTestFailures(store.getState());
        if (Object.keys(failures).length === 0) {
            vorpal.log('No tests failed on the last run.');
            return Promise.resolve();
        }
        const question = {
            name: 'suite',
            message: 'Which failed test suite would you like to run?',
            type: 'list',
            choices: Object.keys(failures)
                .map(k => failures[k])
                .map(f => ({
                name: testFailureName(f),
                value: f.suiteName,
                short: f.suiteName
            }))
        };
        return this.prompt(question)
            .then(({ suite }) => withoutVorpal_1.withoutVorpal(vorpal, () => store.dispatch(nightwatch_1.runTests({ suite }))));
    }),
    vorpal
        .command('env <env>', 'Change current environment')
        .autocomplete({
        data: () => getEnvironments_1.getEnvironments(store.getState())
    })
        .action(({ env: chosenEnv }) => {
        if (!hasEnvironment_1.hasEnvironment(store.getState(), chosenEnv)) {
            vorpal.log(`Unknown env: "${chosenEnv}"`);
            return Promise.resolve();
        }
        store.dispatch(config_1.setCurrentEnvironment({ environment: chosenEnv }));
        return Promise.resolve();
    }),
    vorpal
        .command('state [path]', 'View the internal Night Patrol state')
        .alias('internals')
        .action(({ path: statePath }) => {
        const state = store.getState();
        const internals = statePath ? lodash_1.default.get(state, statePath) : state;
        vorpal.log(JSON.stringify(internals, null, 2));
        return Promise.resolve();
    })
];
exports.createCommonExtension = createCommonExtension;
//# sourceMappingURL=createCommonExtension.js.map