"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRootExtension = void 0;
const config_1 = require("../actions/config");
const nightwatch_1 = require("../actions/nightwatch");
const getHeader_1 = require("../selectors/getHeader");
const getTestCases_1 = require("../selectors/getTestCases");
const getTestSuites_1 = require("../selectors/getTestSuites");
const clearCommands_1 = require("./clearCommands");
const createCommonExtension_1 = require("./createCommonExtension");
const createSuiteExtension_1 = require("./createSuiteExtension");
const useExtensions_1 = require("./useExtensions");
const withoutVorpal_1 = require("./withoutVorpal");
const createRootExtension = (store) => vorpal => {
    store.dispatch(config_1.clearCurrentSuite());
    const commands = [
        vorpal
            .command('list', 'List all test suites')
            .alias('ls')
            .types({ string: ['testname'] })
            .action(() => {
            vorpal.log(getTestSuites_1.getTestSuites(store.getState()).join('\n'));
            return Promise.resolve();
        }),
        vorpal
            .command('run [suite]', 'Run all suites or just one')
            .alias('r')
            .autocomplete({
            data: () => getTestSuites_1.getTestSuites(store.getState())
        })
            .action(({ suite: suiteName }) => withoutVorpal_1.withoutVorpal(vorpal, () => store.dispatch(nightwatch_1.runTests({ suite: suiteName })))),
        vorpal
            .command('suite <suite>', 'Switch to a suite')
            .autocomplete({
            data: () => getTestSuites_1.getTestSuites(store.getState())
        })
            .alias('s', 'cd')
            .action(({ suite: suiteName }) => {
            const testNames = getTestCases_1.getTestCases(store.getState(), suiteName);
            if (!testNames) {
                vorpal.log(`Unknown suite "${suiteName}"`);
                return Promise.resolve();
            }
            clearCommands_1.clearCommands(vorpal);
            useExtensions_1.useExtensions(vorpal, [
                createCommonExtension_1.createCommonExtension(store),
                createSuiteExtension_1.createSuiteExtension(store, suiteName)
            ]);
            return Promise.resolve();
        })
    ];
    vorpal.log(getHeader_1.getHeader(store.getState()));
    vorpal.execSync('help');
    return commands;
};
exports.createRootExtension = createRootExtension;
//# sourceMappingURL=createRootExtension.js.map