"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSuiteExtension = void 0;
const chalk_1 = __importDefault(require("chalk"));
const config_1 = require("../actions/config");
const nightwatch_1 = require("../actions/nightwatch");
const getTestCases_1 = require("../selectors/getTestCases");
const header_1 = require("../utils/header");
const clearCommands_1 = require("./clearCommands");
const createCommonExtension_1 = require("./createCommonExtension");
const createRootExtension_1 = require("./createRootExtension");
const useExtensions_1 = require("./useExtensions");
const withoutVorpal_1 = require("./withoutVorpal");
const createSuiteExtension = (store, suiteName) => {
    return (vorpal) => {
        const goBack = () => {
            clearCommands_1.clearCommands(vorpal);
            useExtensions_1.useExtensions(vorpal, [
                createCommonExtension_1.createCommonExtension(store),
                createRootExtension_1.createRootExtension(store)
            ]);
            return Promise.resolve();
        };
        store.dispatch(config_1.setCurrentSuite({ suite: suiteName }));
        const unsubscribeFromStore = store.subscribe(() => {
            const state = store.getState();
            if (!state.config.suites[suiteName]) {
                vorpal.log('Suite has been removed. Going back.');
                unsubscribeFromStore();
                goBack().catch(e => {
                    console.error(`Failed to go back.`, e);
                    process.exit(1);
                });
            }
        });
        const realSpace = ' ';
        const alternativeSpace = ' ';
        const commands = [
            vorpal
                .command('list', 'List all test cases')
                .alias('ls')
                .types({ string: ['testname'] })
                .action(() => {
                vorpal.log(getTestCases_1.getTestCases(store.getState(), suiteName).join('\n'));
                return Promise.resolve();
            }),
            vorpal
                .command('run [testname]', 'Run all tests or just one')
                .alias('r')
                .autocomplete({
                data() {
                    return getTestCases_1.getTestCases(store.getState(), suiteName)
                        .map(name => `"${name.replace(new RegExp(realSpace, 'g'), alternativeSpace)}"`);
                }
            })
                .types({ string: ['testname'] })
                .action(({ testname: formattedTestName }) => withoutVorpal_1.withoutVorpal(vorpal, () => {
                const testName = formattedTestName
                    ? formattedTestName.replace(new RegExp(alternativeSpace, 'g'), realSpace)
                    : undefined;
                return store.dispatch(nightwatch_1.runTests({
                    suite: suiteName,
                    testname: testName
                }));
            })),
            vorpal
                .command('back', 'Exit suite')
                .alias('b', 'cd ..', 'cd ~', 'cd ~/')
                .action(() => {
                unsubscribeFromStore();
                return goBack();
            })
        ];
        vorpal.log(chalk_1.default.cyan(header_1.header({
            title: `SUITE`,
            subtitle: suiteName
        })));
        vorpal.execSync('help');
        return commands;
    };
};
exports.createSuiteExtension = createSuiteExtension;
//# sourceMappingURL=createSuiteExtension.js.map